
..
    This file maps contributor names to their URLs. It should mostly be used
    for core contributors, and occasionally for contributors who do not want
    their github page to be their URL target. Historically it was used to
    hyperlink all contributors' names, and ``:user:`` should now be preferred.
    It also defines other ReST substitutions.

.. role:: raw-html(raw)
   :format: html

.. role:: raw-latex(raw)
   :format: latex

.. |MajorFeature| replace:: :raw-html:`<span class="badge badge-success">Major Feature</span>` :raw-latex:`{\small\sc [Major Feature]}`
.. |Feature| replace:: :raw-html:`<span class="badge badge-success">Feature</span>` :raw-latex:`{\small\sc [Feature]}`
.. |Efficiency| replace:: :raw-html:`<span class="badge badge-info">Efficiency</span>` :raw-latex:`{\small\sc [Efficiency]}`
.. |Enhancement| replace:: :raw-html:`<span class="badge badge-info">Enhancement</span>` :raw-latex:`{\small\sc [Enhancement]}`
.. |Fix| replace:: :raw-html:`<span class="badge badge-danger">Fix</span>` :raw-latex:`{\small\sc [Fix]}`
.. |API| replace:: :raw-html:`<span class="badge badge-warning">API Change</span>` :raw-latex:`{\small\sc [API Change]}`


.. _Olivier Grisel: https://twitter.com/ogrisel

.. _Gael Varoquaux: http://gael-varoquaux.info

.. _Alexandre Gramfort: http://alexandre.gramfort.net

.. _Fabian Pedregosa: http://fa.bianp.net

.. _Mathieu Blondel: http://www.mblondel.org

.. _James Bergstra: http://www-etud.iro.umontreal.ca/~bergstrj/

.. _liblinear: https://www.csie.ntu.edu.tw/~cjlin/liblinear/

.. _Yaroslav Halchenko: http://www.onerussian.com/

.. _Vlad Niculae: https://vene.ro/

.. _Edouard Duchesnay: https://sites.google.com/site/duchesnay/home

.. _Peter Prettenhofer: https://sites.google.com/site/peterprettenhofer/

.. _Alexandre Passos: http://atpassos.me

.. _Nicolas Pinto: https://twitter.com/npinto

.. _Bertrand Thirion: https://team.inria.fr/parietal/bertrand-thirions-page

.. _Andreas Müller: https://amueller.github.io/

.. _Matthieu Perrot: http://brainvisa.info/biblio/lnao/en/Author/PERROT-M.html

.. _Jake Vanderplas: https://staff.washington.edu/jakevdp/

.. _Gilles Louppe: http://www.montefiore.ulg.ac.be/~glouppe/

.. _INRIA: https://www.inria.fr/

.. _Parietal Team: http://parietal.saclay.inria.fr/

.. _David Warde-Farley: http://www-etud.iro.umontreal.ca/~wardefar/

.. _Brian Holt: http://personal.ee.surrey.ac.uk/Personal/B.Holt

.. _Satrajit Ghosh: https://www.mit.edu/~satra/

.. _Robert Layton: https://twitter.com/robertlayton

.. _Scott White: https://twitter.com/scottblanc

.. _David Marek: https://davidmarek.cz/

.. _Christian Osendorfer: https://osdf.github.io

.. _Arnaud Joly: http://www.ajoly.org

.. _Rob Zinkov: https://www.zinkov.com/

.. _Joel Nothman: https://joelnothman.com/

.. _Nicolas Trésegnie: https://github.com/NicolasTr

.. _Kemal Eren: http://www.kemaleren.com

.. _Yann Dauphin: https://ynd.github.io/

.. _Yannick Schwartz: https://team.inria.fr/parietal/schwarty/

.. _Kyle Kastner: https://kastnerkyle.github.io/

.. _Daniel Nouri: http://danielnouri.org

.. _Manoj Kumar: https://manojbits.wordpress.com

.. _Luis Pedro Coelho: http://luispedro.org

.. _Fares Hedyati: http://www.eecs.berkeley.edu/~fareshed

.. _Antony Lee: https://www.ocf.berkeley.edu/~antonyl/

.. _Martin Billinger: https://tnsre.embs.org/author/martinbillinger/

.. _Matteo Visconti di Oleggio Castello: http://www.mvdoc.me

.. _Trevor Stephens: http://trevorstephens.com/

.. _Jan Hendrik Metzen: https://jmetzen.github.io/

.. _Will Dawson: http://www.dawsonresearch.com

.. _Andrew Tulloch: https://tullo.ch/

.. _Hanna Wallach: https://dirichlet.net/

.. _Yan Yi: http://seowyanyi.org

.. _Hervé Bredin: https://herve.niderb.fr/

.. _Eric Martin: http://www.ericmart.in

.. _Nicolas Goix: https://ngoix.github.io/

.. _Sebastian Raschka: https://sebastianraschka.com/

.. _Brian McFee: https://bmcfee.github.io

.. _Valentin Stolbunov: http://www.vstolbunov.com

.. _Jaques Grobler: https://github.com/jaquesgrobler

.. _Lars Buitinck: https://github.com/larsmans

.. _Loic Esteve: https://github.com/lesteve

.. _Noel Dawe: https://github.com/ndawe

.. _Raghav RV: https://github.com/raghavrv

.. _Tom Dupre la Tour: https://github.com/TomDLT

.. _Nelle Varoquaux: https://github.com/nellev

.. _Bing Tian Dai: https://github.com/btdai

.. _Dylan Werner-Meier: https://github.com/unautre

.. _Alyssa Batula: https://github.com/abatula

.. _Srivatsan Ramesh: https://github.com/srivatsan-ramesh

.. _Ron Weiss: https://www.ee.columbia.edu/~ronw/

.. _Kathleen Chen: https://github.com/kchen17

.. _Vincent Pham: https://github.com/vincentpham1991

.. _Denis Engemann: http://denis-engemann.de

.. _Anish Shah: https://github.com/AnishShah

.. _Neeraj Gangwar: http://neerajgangwar.in

.. _Arthur Mensch: https://amensch.fr

.. _Joris Van den Bossche: https://github.com/jorisvandenbossche

.. _Roman Yurchak: https://github.com/rth

.. _Hanmin Qin: https://github.com/qinhanmin2014

.. _Adrin Jalali: https://github.com/adrinjalali

.. _Thomas Fan: https://github.com/thomasjpfan

.. _Nicolas Hug: https://github.com/NicolasHug

.. _Guillaume Lemaitre: https://github.com/glemaitre